@@ -1,12 +1,12 @@
 package HTML::Latemp::GenMakeHelpers;
-$HTML::Latemp::GenMakeHelpers::VERSION = '0.8.0';
+$HTML::Latemp::GenMakeHelpers::VERSION = '0.10.0';
 use strict;
 use warnings;
 use autodie;
 use 5.014;
 
 package HTML::Latemp::GenMakeHelpers::Base;
-$HTML::Latemp::GenMakeHelpers::Base::VERSION = '0.8.0';
+$HTML::Latemp::GenMakeHelpers::Base::VERSION = '0.10.0';
 sub new
 {
     my $class = shift;
@@ -17,7 +17,7 @@ sub new
 }
 
 package HTML::Latemp::GenMakeHelpers::HostEntry;
-$HTML::Latemp::GenMakeHelpers::HostEntry::VERSION = '0.8.0';
+$HTML::Latemp::GenMakeHelpers::HostEntry::VERSION = '0.10.0';
 our @ISA = (qw(HTML::Latemp::GenMakeHelpers::Base));
 
 use Class::XSAccessor accessors =>
@@ -34,11 +34,11 @@ sub initialize
 }
 
 package HTML::Latemp::GenMakeHelpers::Error;
-$HTML::Latemp::GenMakeHelpers::Error::VERSION = '0.8.0';
+$HTML::Latemp::GenMakeHelpers::Error::VERSION = '0.10.0';
 our @ISA = (qw(HTML::Latemp::GenMakeHelpers::Base));
 
 package HTML::Latemp::GenMakeHelpers::Error::UncategorizedFile;
-$HTML::Latemp::GenMakeHelpers::Error::UncategorizedFile::VERSION = '0.8.0';
+$HTML::Latemp::GenMakeHelpers::Error::UncategorizedFile::VERSION = '0.10.0';
 our @ISA = (qw(HTML::Latemp::GenMakeHelpers::Error));
 
 use Class::XSAccessor accessors => { 'file' => 'file', 'host' => 'host', };
@@ -354,31 +354,31 @@ qq#$wml_path ; ( cd \$(X8X_SRC_DIR) && wml -o "\$\${WML_LATEMP_PATH}" \$(X8X_WML
     my $nci_h_dest_star = "\$($no_common_images_dest)/%";
     return <<"EOF";
 
-X8X_SRC_DIR = $source_dir_path
+X8X_SRC_DIR := $source_dir_path
 
-X8X_DEST = $dest_dir
+X8X_DEST := $dest_dir
 
-X8X_TARGETS = \$(X8X_DEST) \$(X8X_DIRS_DEST) \$(X8X_COMMON_DIRS_DEST) \$(X8X_COMMON_IMAGES_DEST) \$(X8X_COMMON_DOCS_DEST) \$(X8X_COMMON_TTMLS_DEST) \$(X8X_IMAGES_DEST) \$(X8X_DOCS_DEST) \$(X8X_TTMLS_DEST)
+X8X_WML_FLAGS := \$(WML_FLAGS) -DLATEMP_SERVER=x8x
 
-X8X_WML_FLAGS = \$(WML_FLAGS) -DLATEMP_SERVER=x8x
+X8X_TTML_FLAGS := \$(TTML_FLAGS) -DLATEMP_SERVER=x8x
 
-X8X_TTML_FLAGS = \$(TTML_FLAGS) -DLATEMP_SERVER=x8x
+X8X_DOCS_DEST := \$(patsubst %,\$(X8X_DEST)/%,\$(X8X_DOCS))
 
-X8X_DOCS_DEST = \$(patsubst %,\$(X8X_DEST)/%,\$(X8X_DOCS))
+X8X_DIRS_DEST := \$(patsubst %,\$(X8X_DEST)/%,\$(X8X_DIRS))
 
-X8X_DIRS_DEST = \$(patsubst %,\$(X8X_DEST)/%,\$(X8X_DIRS))
+X8X_IMAGES_DEST := \$(patsubst %,\$($no_common_images_dest)/%,\$(X8X_IMAGES))
 
-X8X_IMAGES_DEST = \$(patsubst %,\$($no_common_images_dest)/%,\$(X8X_IMAGES))
+X8X_TTMLS_DEST := \$(patsubst %,\$(X8X_DEST)/%,\$(X8X_TTMLS))
 
-X8X_TTMLS_DEST = \$(patsubst %,\$(X8X_DEST)/%,\$(X8X_TTMLS))
+X8X_COMMON_IMAGES_DEST := \$(patsubst %,\$($common_images_dest)/%,\$(COMMON_IMAGES))
 
-X8X_COMMON_IMAGES_DEST = \$(patsubst %,\$($common_images_dest)/%,\$(COMMON_IMAGES))
+X8X_COMMON_DIRS_DEST := \$(patsubst %,\$(X8X_DEST)/%,\$(COMMON_DIRS))
 
-X8X_COMMON_DIRS_DEST = \$(patsubst %,\$(X8X_DEST)/%,\$(COMMON_DIRS))
+X8X_COMMON_TTMLS_DEST := \$(patsubst %,\$(X8X_DEST)/%,\$(COMMON_TTMLS))
 
-X8X_COMMON_TTMLS_DEST = \$(patsubst %,\$(X8X_DEST)/%,\$(COMMON_TTMLS))
+X8X_COMMON_DOCS_DEST := \$(patsubst %,\$(X8X_DEST)/%,\$(COMMON_DOCS))
 
-X8X_COMMON_DOCS_DEST = \$(patsubst %,\$(X8X_DEST)/%,\$(COMMON_DOCS))
+X8X_TARGETS := \$(X8X_DEST) \$(X8X_DIRS_DEST) \$(X8X_COMMON_DIRS_DEST) \$(X8X_COMMON_IMAGES_DEST) \$(X8X_COMMON_DOCS_DEST) \$(X8X_COMMON_TTMLS_DEST) \$(X8X_IMAGES_DEST) \$(X8X_DOCS_DEST) \$(X8X_TTMLS_DEST)
 
 \$(X8X_DOCS_DEST) : $h_dest_star : \$(X8X_SRC_DIR)/%${out_docs_ext} \$(DOCS_COMMON_DEPS)
 	$no_common_cmd
@@ -438,7 +438,7 @@ sub process_host
         my $name = $bucket->{name};
         $file_lists_text .=
               $host_uc . "_"
-            . $name . " ="
+            . $name . " :="
             . join(
             "",
             map { " $_" } @{
@@ -478,7 +478,7 @@ __END__
 
 =head1 VERSION
 
-version 0.8.0
+version 0.10.0
 
 =head1 SYNOPSIS
 
@@ -498,7 +498,7 @@ version 0.8.0
 
 =head1 VERSION
 
-version 0.8.0
+version 0.10.0
 
 =head1 NAME
 
@@ -607,7 +607,7 @@ Copyright 2005 Shlomi Fish, All Rights Reserved.
 This program is free software; you can redistribute it and/or modify it
 under the MIT X11 License.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -644,14 +644,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Latemp-GenMakeHelpers>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/HTML-Latemp-GenMakeHelpers>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
@@ -731,7 +723,7 @@ This is free software, licensed under:
 
   The MIT (X11) License
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -768,14 +760,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Latemp-GenMakeHelpers>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/HTML-Latemp-GenMakeHelpers>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
